@@ -5,29 +5,32 @@ Created on Fri Jun 21 13:24:31 2019
 
 @author: gbuster
 """
-import pandas as pd
-import numpy as np
-from warnings import warn
 import logging
+import numpy as np
+import pandas as pd
 from scipy import stats
+from warnings import warn
 
+
+from reV.utilities.utilities import jsonify_dict
 from reV.handlers.exclusions import ExclusionLayers
-from reV.supply_curve.points import SupplyCurvePoint
+from reV.supply_curve.points import GenerationSupplyCurvePoint
 from reV.utilities.exceptions import (EmptySupplyCurvePointError,
-                                      OutputWarning, FileInputError)
+                                      OutputWarning, FileInputError,
+                                      DataShapeError)
 
 
 logger = logging.getLogger(__name__)
 
 
-class SupplyCurvePointSummary(SupplyCurvePoint):
+class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
     """Supply curve summary framework with extra methods for summary calc."""
 
     # technology-dependent power density estimates in MW/km2
     POWER_DENSITY = {'pv': 36, 'wind': 3}
 
     def __init__(self, gid, excl, gen, tm_dset, gen_index, excl_dict=None,
-                 res_class_dset=None, res_class_bin=None, ex_area=0.0081,
+                 res_class_dset=None, res_class_bin=None, excl_area=0.0081,
                  power_density=None, cf_dset='cf_mean-means',
                  lcoe_dset='lcoe_fcr-means', resolution=64,
                  exclusion_shape=None, close=False, offshore_flags=None,
@@ -59,7 +62,7 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
         res_class_bin : list | None
             Two-entry lists dictating the single resource class bin.
             None if no resource classes.
-        ex_area : float
+        excl_area : float
             Area of an exclusion cell (square km).
         power_density : float | None | pd.DataFrame
             Constant power density float, None, or opened dataframe with
@@ -89,20 +92,17 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
         self._res_class_bin = res_class_bin
         self._cf_dset = cf_dset
         self._lcoe_dset = lcoe_dset
-        self._res_gid_set = None
-        self._gen_gid_set = None
         self._mean_res = None
         self._res_data = None
         self._gen_data = None
         self._lcoe_data = None
-        self._ex_area = ex_area
         self._pd_obj = None
         self._power_density = power_density
         self._friction_layer = friction_layer
 
         super().__init__(gid, excl, gen, tm_dset, gen_index,
                          excl_dict=excl_dict, resolution=resolution,
-                         exclusion_shape=exclusion_shape,
+                         excl_area=excl_area, exclusion_shape=exclusion_shape,
                          offshore_flags=offshore_flags, close=close)
 
         self._apply_exclusions()
@@ -156,36 +156,6 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
 
         return boolean_exclude
 
-    @staticmethod
-    def ordered_unique(seq):
-        """Get a list of unique values in the same order as the input sequence.
-
-        Parameters
-        ----------
-        seq : list | tuple
-            Sequence of values.
-
-        Returns
-        -------
-        seq : list
-            List of unique values in seq input with original order.
-        """
-
-        seen = set()
-        return [x for x in seq if not (x in seen or seen.add(x))]
-
-    @property
-    def area(self):
-        """Get the non-excluded resource area of the supply curve point in the
-        current resource class.
-
-        Returns
-        -------
-        area : float
-            Non-excluded resource/generation area in square km.
-        """
-        return self.excl_data.sum() * self._ex_area
-
     @property
     def res_data(self):
         """Get the resource data array.
@@ -249,125 +219,6 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
 
         return self._lcoe_data
 
-    @property
-    def latitude(self):
-        """Get the SC point latitude"""
-        return self.centroid[0]
-
-    @property
-    def longitude(self):
-        """Get the SC point longitude"""
-        return self.centroid[1]
-
-    @property
-    def country(self):
-        """Get the SC point country based on the resource meta data."""
-        country = None
-        if 'country' in self.gen.meta:
-            country = self.gen.meta.loc[self.gen_gid_set, 'country'].values
-            country = stats.mode(country).mode[0]
-
-        return country
-
-    @property
-    def state(self):
-        """Get the SC point state based on the resource meta data."""
-        state = None
-        if 'state' in self.gen.meta:
-            state = self.gen.meta.loc[self.gen_gid_set, 'state'].values
-            state = stats.mode(state).mode[0]
-
-        return state
-
-    @property
-    def county(self):
-        """Get the SC point county based on the resource meta data."""
-        county = None
-        if 'county' in self.gen.meta:
-            county = self.gen.meta.loc[self.gen_gid_set, 'county'].values
-            county = stats.mode(county).mode[0]
-
-        return county
-
-    @property
-    def elevation(self):
-        """Get the SC point elevation based on the resource meta data."""
-        elevation = None
-        if 'elevation' in self.gen.meta:
-            elevation = self.gen.meta.loc[self.gen_gid_set, 'elevation'].mean()
-
-        return elevation
-
-    @property
-    def timezone(self):
-        """Get the SC point timezone based on the resource meta data."""
-        timezone = None
-        if 'timezone' in self.gen.meta:
-            timezone = self.gen.meta.loc[self.gen_gid_set, 'timezone'].values
-            timezone = stats.mode(timezone).mode[0]
-
-        return timezone
-
-    @property
-    def res_gid_set(self):
-        """Get list of unique resource gids corresponding to this sc point.
-
-        Returns
-        -------
-        res_gids : list
-            List of resource gids.
-        """
-        if self._res_gid_set is None:
-            self._res_gid_set = self.ordered_unique(self._res_gids)
-            if -1 in self._res_gid_set:
-                self._res_gid_set.remove(-1)
-
-        return self._res_gid_set
-
-    @property
-    def gen_gid_set(self):
-        """Get list of unique generation gids corresponding to this sc point.
-
-        Returns
-        -------
-        gen_gids : list
-            List of generation gids.
-        """
-        if self._gen_gid_set is None:
-            self._gen_gid_set = self.ordered_unique(self._gen_gids)
-            if -1 in self._gen_gid_set:
-                self._gen_gid_set.remove(-1)
-
-        return self._gen_gid_set
-
-    @property
-    def gid_counts(self):
-        """Get the number of exclusion pixels in each resource/generation gid
-        corresponding to this sc point.
-
-        Returns
-        -------
-        gid_counts : list
-            List of exclusion pixels in each resource/generation gid.
-        """
-        gid_counts = [self.excl_data_flat[(self._res_gids == gid)].sum()
-                      for gid in self.res_gid_set]
-        return gid_counts
-
-    @property
-    def n_gids(self):
-        """
-        Get the total number of resource/generation gids that were at
-        not excluded.
-
-        Returns
-        -------
-        n_gids : list
-            List of exclusion pixels in each resource/generation gid.
-        """
-        n_gids = np.sum(self.excl_data_flat > 0)
-        return n_gids
-
     @property
     def mean_cf(self):
         """Get the mean capacity factor for the non-excluded data. Capacity
@@ -556,6 +407,8 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
                     nodata = attrs['fobj'].get_nodata_value(attrs['dset'])
 
                 data = raw.flatten()[self.bool_mask]
+                excl_mult = self.excl_data_flat[self.bool_mask]
+
                 if nodata is not None:
                     nodata_mask = (data == nodata)
 
@@ -563,12 +416,15 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
                     # Reset data from raw without exclusions.
                     if all(nodata_mask):
                         data = raw.flatten()
+                        excl_mult = self.excl_data_flat
                         nodata_mask = (data == nodata)
 
                     data = data[~nodata_mask]
+                    excl_mult = excl_mult[~nodata_mask]
 
                     if not data.size:
                         data = None
+                        excl_mult = None
                         w = ('Data layer "{}" has no valid data for '
                              'SC point gid {} at ({}, {})!'
                              .format(name, self._gid, self.latitude,
@@ -576,13 +432,14 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
                         logger.warning(w)
                         warn(w, OutputWarning)
 
-                data = self._agg_data_layer_method(data, attrs['method'])
+                data = self._agg_data_layer_method(data, excl_mult,
+                                                   attrs['method'])
                 summary[name] = data
 
         return summary
 
     @staticmethod
-    def _agg_data_layer_method(data, method):
+    def _agg_data_layer_method(data, excl_mult, method):
         """Aggregate the data array using specified method.
 
         Parameters
@@ -591,16 +448,25 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
             Data array that will be flattened and operated on using method.
             This must be the included data. Exclusions should be applied
             before this method.
+        excl_mult : np.ndarray | None
+            Scalar exclusion data for methods with exclusion-weighted
+            aggregation methods. Shape must match input data.
         method : str
-            Aggregation method (mode, mean, sum)
+            Aggregation method (mode, mean, sum, category)
 
         Returns
         -------
-        data : float | int | None
+        data : float | int | str | None
             Result of applying method to data.
         """
         if data is not None:
 
+            if data.shape != excl_mult.shape:
+                e = ('Cannot aggregate data with shape that doesnt '
+                     'match excl mult!')
+                logger.error(e)
+                raise DataShapeError(e)
+
             if len(data.shape) > 1:
                 data = data.flatten()
 
@@ -610,17 +476,22 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
                 data = data.mean()
             elif method.lower() == 'sum':
                 data = data.sum()
+            elif method.lower() == 'category':
+                data = {category: float(excl_mult[(data == category)].sum())
+                        for category in np.unique(data)}
+                data = jsonify_dict(data)
             else:
                 e = ('Cannot recognize data layer agg method: '
-                     '"{}". Can only do mean, mode, and sum.'
+                     '"{}". Can only do mean, mode, sum, or category.'
                      .format(method))
                 logger.error(e)
                 raise ValueError(e)
+
         return data
 
     def summarize(self, args=None, data_layers=None):
         """
-        [summary]
+        Get a summary dictionary of a single supply curve point.
 
         Parameters
         ----------
@@ -670,13 +541,12 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
         return summary
 
     @classmethod
-    def summary(cls, gid, excl_fpath, gen_fpath, tm_dset,
-                gen_index, args=None, data_layers=None,
+    def summary(cls, gid, excl_fpath, gen_fpath, tm_dset, gen_index,
                 excl_dict=None, res_class_dset=None, res_class_bin=None,
-                ex_area=0.0081, power_density=None,
-                cf_dset='cf_mean-means', lcoe_dset='lcoe_fcr-means',
-                resolution=64, exclusion_shape=None, close=False,
-                offshore_flags=None, friction_layer=None):
+                excl_area=0.0081, power_density=None, cf_dset='cf_mean-means',
+                lcoe_dset='lcoe_fcr-means', resolution=64,
+                exclusion_shape=None, close=False, offshore_flags=None,
+                friction_layer=None, args=None, data_layers=None):
         """Get a summary dictionary of a single supply curve point.
 
         Parameters
@@ -684,23 +554,16 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
         gid : int
             gid for supply curve point to analyze.
         excl_fpath : str
-            Filepath to exclusions geotiff.
+            Filepath to exclusions h5.
         gen_fpath : str
             Filepath to .h5 reV generation output results.
         tm_dset : str
             Dataset name in the techmap file containing the
-            exclusions-to-generation mapping data.
+            exclusions-to-resource mapping data.
         gen_index : np.ndarray
             Array of generation gids with array index equal to resource gid.
             Array value is -1 if the resource index was not used in the
             generation run.
-        args : tuple | list | None
-            List of summary arguments to include. None defaults to all
-            available args defined in the class attr.
-        data_layers : None | dict
-            Aggregation data layers. Must be a dictionary keyed by data label
-            name. Each value must be another dictionary with "dset", "method",
-            and "fpath".
         excl_dict : dict | None
             Dictionary of exclusion LayerMask arugments {layer: {kwarg: value}}
             None if excl input is pre-initialized.
@@ -711,7 +574,7 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
         res_class_bin : list | None
             Two-entry lists dictating the single resource class bin.
             None if no resource classes.
-        ex_area : float
+        excl_area : float
             Area of an exclusion cell (square km).
         power_density : float | None | pd.DataFrame
             Constant power density float, None, or opened dataframe with
@@ -732,9 +595,16 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
         offshore_flags : np.ndarray | None
             Array of offshore boolean flags if available from wind generation
             data. None if offshore flag is not available.
-        friction_layer : None | ExclusionMask
+        friction_layer : None | FrictionMask
             Friction layer with scalar friction values if valid friction inputs
             were entered. Otherwise, None to not apply friction layer.
+        args : tuple | list, optional
+            List of summary arguments to include. None defaults to all
+            available args defined in the class attr, by default None
+        data_layers : dict, optional
+            Aggregation data layers. Must be a dictionary keyed by data label
+            name. Each value must be another dictionary with "dset", "method",
+            and "fpath", by default None
 
         Returns
         -------
@@ -742,7 +612,7 @@ class SupplyCurvePointSummary(SupplyCurvePoint):
             Dictionary of summary outputs for this sc point.
         """
         kwargs = {"excl_dict": excl_dict, "res_class_dset": res_class_dset,
-                  "res_class_bin": res_class_bin, "ex_area": ex_area,
+                  "res_class_bin": res_class_bin, "excl_area": excl_area,
                   "power_density": power_density, "cf_dset": cf_dset,
                   "lcoe_dset": lcoe_dset, "resolution": resolution,
                   "exclusion_shape": exclusion_shape, "close": close,
