@@ -5,4 +5,4 @@ reV utilities.
 from .execution import SmartParallelJob
 from .loggers import init_logger, init_mult, setup_logger
 from .solar_position import SolarPosition
-from .utilities import safe_json_load, parse_year, check_res_file
+from .utilities import safe_json_load, jsonify_dict, parse_year, check_res_file
